# libpythonpro_ravellys
Módulo para exemplificar modulos em python PyTools

Nesse curso é ensinado como contribuir em projetos de código aberto

Link do site [Python Pro](https://python.pro.br/)

[![Build Status](https://travis-ci.com/ravellys/libpythonpro_ravellys.svg?branch=master)](https://travis-ci.com/ravellys/libpythonpro_ravellys)
[![Updates](https://pyup.io/repos/github/ravellys/libpythonpro_ravellys/shield.svg)](https://pyup.io/repos/github/ravellys/libpythonpro_ravellys/)
[![Python 3](https://pyup.io/repos/github/ravellys/libpythonpro_ravellys/python-3-shield.svg)](https://pyup.io/repos/github/ravellys/libpythonpro_ravellys/)

Suportada versão 3 de python.

Para instalar:
```
py -3.8 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:
```
flak8
```

Tópicos a serem abordados:
1. Git
2. Venv
3. Pip